@@ -7,7 +7,7 @@ def is_inside_reaper():
 
     If ``reapy`` is run from inside a REAPER instance but currently
     controls another REAPER instance on a slave machine (with
-    ``reapy.machines.select_machine``), return False.
+    ``reapy.connect``), return False.
     """
     inside = hasattr(sys.modules["__main__"], "obj")
     if not inside:
@@ -27,8 +27,9 @@ from .tools import (
     reconnect
 )
 from . import reascript_api
+from .config import configure_reaper
 from .core import *
 from .core.reaper import *
 
 
-__version__ = "0.7.2"
+__version__ = "0.8.0"
